@@ -978,7 +978,7 @@ async def test_pagination_post(app_client, load_test_data, load_test_collection)
         idx += 1
         page_data = page.json()
         item_ids.append(page_data["features"][0]["id"])
-        next_link = list(filter(lambda l: l["rel"] == "next", page_data["links"]))
+        next_link = list(filter(lambda link: link["rel"] == "next", page_data["links"]))
         if not next_link:
             break
         # Merge request bodies
@@ -1021,7 +1021,7 @@ async def test_pagination_token_idempotent(
         },
     )
     page_data = page.json()
-    next_link = list(filter(lambda l: l["rel"] == "next", page_data["links"]))
+    next_link = list(filter(lambda link: link["rel"] == "next", page_data["links"]))
 
     # Confirm token is idempotent
     resp1 = await app_client.get(
